DueDil API v3 |pypi| |build-status| |coverage-status| |waffle| |docs|
=====================================================================

This is a Python implementation of the `DueDil v3 API`_, see the generated
`documentation <http://duedilv3.readthedocs.org/en/latest/>`_ for more information.

.. |build-status| image:: https://travis-ci.org/founders4schools/duedilv3.svg?branch=master
    :target: https://travis-ci.org/founders4schools/duedilv3
    :alt: Build
.. |coverage-status| image:: https://coveralls.io/repos/founders4schools/duedilv3/badge.png
    :target: https://coveralls.io/r/founders4schools/duedilv3
    :alt: Coverage
.. |pypi| image:: https://badge.fury.io/py/duedil.svg
    :target: http://badge.fury.io/py/duedil
    :alt: PyPi Status
.. |waffle| image:: https://badge.waffle.io/founders4schools/duedilv3.png?label=ready&title=Ready
    :target: https://waffle.io/founders4schools/duedilv3
    :alt: 'Stories in Ready'

.. |docs| image:: https://readthedocs.org/projects/duedilv3/badge/?version=latest
    :target: https://readthedocs.org/projects/duedilv3/?badge=latest
    :alt: Documentation Status
.. _DueDil v3 API: https://developer.duedil.com/
